==> ejc-ztpcct-impl-3.0.0-20231214.070836-66-sources.jar: com/ejianc/ztpc/bean/ProjectDisclosureEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目交底表
 *
 * @author generator
 */
@TableName("ct_project_disclosure")
public class ProjectDisclosureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "code")
    private String code; // 编码
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 项目组织ID
    @TableField(value = "org_code")
    private String orgCode; // 项目组织编码
    @TableField(value = "org_name")
    private String orgName; // 项目组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "cons_scheme_id")
    private Long consSchemeId; // 施工方案ID
    @TableField(value = "cons_scheme_code")
    private String consSchemeCode; // 施工方案编码
    @TableField(value = "cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value = "cons_scheme_file_version")
    private String consSchemeFileVersion; // 施工方案文件版次
    @TableField(value = "internal_code")
    private String internalCode; // 内部编码
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典mgrp
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典specialty
    @TableField(value = "build_unit")
    private Long buildUnit; // 施工单位
    @TableField(value = "build_leader")
    private Long buildLeader; // 施工负责人
    @TableField(value = "redact_user")
    private Long redactUser; // 编制人
    @TableField(value = "redact_date")
    private Date redactDate; // 编制日期
    @TableField(value = "audit_user")
    private Long auditUser; // 审核人
    @TableField(value = "audit_date")
    private Date auditDate; // 审核日期
    @TableField(value = "place")
    private String place; // 地点
    @TableField(value = "disclosure_name")
    private String disclosureName; // 交底名称
    @TableField(value = "disclosure_type")
    private Long disclosureType; // 交底类型
    @TableField(value = "disclosure_version")
    private String disclosureVersion; // 交底版本
    @TableField(value = "disclosure_date")
    private Date disclosureDate; // 交底时间
    @TableField(value = "disclosure_user")
    private Long disclosureUser; // 交底人
    @TableField(value = "by_disclosure_dept")
    private Long byDisclosureDept; // 被交底部门/班组
    @TableField(value = "remark")
    private String remark; // 备注
    @TableField(value = "disclosure_record_file")
    private String disclosureRecordFile; // 交底记录附件
    @TableField(value = "engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value = "project_leave")
    private Long projectLeave; // 项目分级(自定义档案)

    @TableField(exist = false)
    @SubEntity(serviceName = "byDisclosureUserService")
    private List<ByDisclosureUserEntity> byDisclosureUserList; // 被交底人员


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getConsSchemeId() {
        return consSchemeId;
    }

    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }

    public String getConsSchemeCode() {
        return consSchemeCode;
    }

    public void setConsSchemeCode(String consSchemeCode) {
        this.consSchemeCode = consSchemeCode;
    }

    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }

    public String getConsSchemeFileVersion() {
        return consSchemeFileVersion;
    }

    public void setConsSchemeFileVersion(String consSchemeFileVersion) {
        this.consSchemeFileVersion = consSchemeFileVersion;
    }

    public String getInternalCode() {
        return internalCode;
    }

    public void setInternalCode(String internalCode) {
        this.internalCode = internalCode;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getBuildUnit() {
        return buildUnit;
    }

    public void setBuildUnit(Long buildUnit) {
        this.buildUnit = buildUnit;
    }

    public Long getBuildLeader() {
        return buildLeader;
    }

    public void setBuildLeader(Long buildLeader) {
        this.buildLeader = buildLeader;
    }

    public Long getRedactUser() {
        return redactUser;
    }

    public void setRedactUser(Long redactUser) {
        this.redactUser = redactUser;
    }

    public Date getRedactDate() {
        return redactDate;
    }

    public void setRedactDate(Date redactDate) {
        this.redactDate = redactDate;
    }

    public Long getAuditUser() {
        return auditUser;
    }

    public void setAuditUser(Long auditUser) {
        this.auditUser = auditUser;
    }

    public Date getAuditDate() {
        return auditDate;
    }

    public void setAuditDate(Date auditDate) {
        this.auditDate = auditDate;
    }

    public String getPlace() {
        return place;
    }

    public void setPlace(String place) {
        this.place = place;
    }

    public String getDisclosureName() {
        return disclosureName;
    }

    public void setDisclosureName(String disclosureName) {
        this.disclosureName = disclosureName;
    }

    public Long getDisclosureType() {
        return disclosureType;
    }

    public void setDisclosureType(Long disclosureType) {
        this.disclosureType = disclosureType;
    }

    public String getDisclosureVersion() {
        return disclosureVersion;
    }

    public void setDisclosureVersion(String disclosureVersion) {
        this.disclosureVersion = disclosureVersion;
    }

    public Date getDisclosureDate() {
        return disclosureDate;
    }

    public void setDisclosureDate(Date disclosureDate) {
        this.disclosureDate = disclosureDate;
    }

    public Long getDisclosureUser() {
        return disclosureUser;
    }

    public void setDisclosureUser(Long disclosureUser) {
        this.disclosureUser = disclosureUser;
    }

    public Long getByDisclosureDept() {
        return byDisclosureDept;
    }

    public void setByDisclosureDept(Long byDisclosureDept) {
        this.byDisclosureDept = byDisclosureDept;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getDisclosureRecordFile() {
        return disclosureRecordFile;
    }

    public void setDisclosureRecordFile(String disclosureRecordFile) {
        this.disclosureRecordFile = disclosureRecordFile;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }

    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }

    public List<ByDisclosureUserEntity> getByDisclosureUserList() {
        return byDisclosureUserList;
    }

    public void setByDisclosureUserList(List<ByDisclosureUserEntity> byDisclosureUserList) {
        this.byDisclosureUserList = byDisclosureUserList;
    }
}

==> ejc-ztpcct-impl-3.0.0-20240314.091221-101-sources.jar: com/ejianc/ztpc/bean/ProjectDisclosureEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目交底表
 *
 * @author generator
 */
@TableName("ct_project_disclosure")
public class ProjectDisclosureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "code")
    private String code; // 编码
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 项目组织ID
    @TableField(value = "org_code")
    private String orgCode; // 项目组织编码
    @TableField(value = "org_name")
    private String orgName; // 项目组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "cons_scheme_id")
    private Long consSchemeId; // 施工方案ID
    @TableField(value = "cons_scheme_code")
    private String consSchemeCode; // 施工方案编码
    @TableField(value = "cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value = "cons_scheme_file_version")
    private String consSchemeFileVersion; // 施工方案文件版次
    @TableField(value = "internal_code")
    private String internalCode; // 内部编码
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典mgrp
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典specialty
    @TableField(value = "build_unit")
    private Long buildUnit; // 施工单位
    @TableField(value = "build_leader")
    private Long buildLeader; // 施工负责人
    @TableField(value = "redact_user")
    private Long redactUser; // 编制人
    @TableField(value = "redact_date")
    private Date redactDate; // 编制日期
    @TableField(value = "audit_user")
    private Long auditUser; // 审核人
    @TableField(value = "audit_date")
    private Date auditDate; // 审核日期
    @TableField(value = "place")
    private String place; // 地点
    @TableField(value = "disclosure_name")
    private String disclosureName; // 交底名称
    @TableField(value = "disclosure_type")
    private Long disclosureType; // 交底类型
    @TableField(value = "disclosure_version")
    private String disclosureVersion; // 交底版本
    @TableField(value = "disclosure_date")
    private Date disclosureDate; // 交底时间
    @TableField(value = "disclosure_user")
    private Long disclosureUser; // 交底人
    @TableField(value = "by_disclosure_dept")
    private Long byDisclosureDept; // 被交底部门/班组
    @TableField(value = "remark")
    private String remark; // 备注
    @TableField(value = "disclosure_record_file")
    private String disclosureRecordFile; // 交底记录附件
    @TableField(value = "engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value = "project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value = "outside_code")
    private String outsideCode;// 外部编码

    @TableField(exist = false)
    @SubEntity(serviceName = "byDisclosureUserService")
    private List<ByDisclosureUserEntity> byDisclosureUserList; // 被交底人员


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getConsSchemeId() {
        return consSchemeId;
    }

    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }

    public String getConsSchemeCode() {
        return consSchemeCode;
    }

    public void setConsSchemeCode(String consSchemeCode) {
        this.consSchemeCode = consSchemeCode;
    }

    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }

    public String getConsSchemeFileVersion() {
        return consSchemeFileVersion;
    }

    public void setConsSchemeFileVersion(String consSchemeFileVersion) {
        this.consSchemeFileVersion = consSchemeFileVersion;
    }

    public String getInternalCode() {
        return internalCode;
    }

    public void setInternalCode(String internalCode) {
        this.internalCode = internalCode;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getBuildUnit() {
        return buildUnit;
    }

    public void setBuildUnit(Long buildUnit) {
        this.buildUnit = buildUnit;
    }

    public Long getBuildLeader() {
        return buildLeader;
    }

    public void setBuildLeader(Long buildLeader) {
        this.buildLeader = buildLeader;
    }

    public Long getRedactUser() {
        return redactUser;
    }

    public void setRedactUser(Long redactUser) {
        this.redactUser = redactUser;
    }

    public Date getRedactDate() {
        return redactDate;
    }

    public void setRedactDate(Date redactDate) {
        this.redactDate = redactDate;
    }

    public Long getAuditUser() {
        return auditUser;
    }

    public void setAuditUser(Long auditUser) {
        this.auditUser = auditUser;
    }

    public Date getAuditDate() {
        return auditDate;
    }

    public void setAuditDate(Date auditDate) {
        this.auditDate = auditDate;
    }

    public String getPlace() {
        return place;
    }

    public void setPlace(String place) {
        this.place = place;
    }

    public String getDisclosureName() {
        return disclosureName;
    }

    public void setDisclosureName(String disclosureName) {
        this.disclosureName = disclosureName;
    }

    public Long getDisclosureType() {
        return disclosureType;
    }

    public void setDisclosureType(Long disclosureType) {
        this.disclosureType = disclosureType;
    }

    public String getDisclosureVersion() {
        return disclosureVersion;
    }

    public void setDisclosureVersion(String disclosureVersion) {
        this.disclosureVersion = disclosureVersion;
    }

    public Date getDisclosureDate() {
        return disclosureDate;
    }

    public void setDisclosureDate(Date disclosureDate) {
        this.disclosureDate = disclosureDate;
    }

    public Long getDisclosureUser() {
        return disclosureUser;
    }

    public void setDisclosureUser(Long disclosureUser) {
        this.disclosureUser = disclosureUser;
    }

    public Long getByDisclosureDept() {
        return byDisclosureDept;
    }

    public void setByDisclosureDept(Long byDisclosureDept) {
        this.byDisclosureDept = byDisclosureDept;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getDisclosureRecordFile() {
        return disclosureRecordFile;
    }

    public void setDisclosureRecordFile(String disclosureRecordFile) {
        this.disclosureRecordFile = disclosureRecordFile;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }

    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }

    public List<ByDisclosureUserEntity> getByDisclosureUserList() {
        return byDisclosureUserList;
    }

    public void setByDisclosureUserList(List<ByDisclosureUserEntity> byDisclosureUserList) {
        this.byDisclosureUserList = byDisclosureUserList;
    }

    public String getOutsideCode() {
        return outsideCode;
    }

    public void setOutsideCode(String outsideCode) {
        this.outsideCode = outsideCode;
    }
}
